import * as solid_js from 'solid-js';

interface EyeDropperOpenOptions {
    /**
     * @see https://developer.mozilla.org/en-US/docs/Web/API/AbortSignal
     */
    signal?: AbortSignal;
}
interface EyeDropper {
    new (): EyeDropper;
    open: (options?: EyeDropperOpenOptions) => Promise<{
        sRGBHex: string;
    }>;
    [Symbol.toStringTag]: 'EyeDropper';
}
interface UseEyeDropperOptions {
    /**
     * Initial sRGBHex.
     *
     * @default ''
     */
    initialValue?: string;
}
/**
 * Reactive [EyeDropper API](https://developer.mozilla.org/en-US/docs/Web/API/EyeDropper_API)
 *
 * @see https://solidjs-use.github.io/solidjs-use/core/useEyeDropper
 */
declare function useEyeDropper(options?: UseEyeDropperOptions): {
    isSupported: solid_js.Accessor<boolean>;
    sRGBHex: solid_js.Accessor<string>;
    open: (openOptions?: EyeDropperOpenOptions) => Promise<{
        sRGBHex: string;
    } | undefined>;
};
type UseEyeDropperReturn = ReturnType<typeof useEyeDropper>;

export { EyeDropper, EyeDropperOpenOptions, UseEyeDropperOptions, UseEyeDropperReturn, useEyeDropper };
