import { EventHookOn } from '@solidjs-use/shared';
import { Accessor } from 'solid-js';
import { ConfigurableDocument } from '../_configurable.js';

interface UseFileDialogOptions extends ConfigurableDocument {
    /**
     * @default true
     */
    multiple?: boolean;
    /**
     * @default '*'
     */
    accept?: string;
    /**
     * Select the input source for the capture file.
     * @see [HTMLInputElement Capture](https://developer.mozilla.org/en-US/docs/Web/HTML/Attributes/capture)
     */
    capture?: string;
    /**
     * Reset when open file dialog.
     * @default false
     */
    reset?: boolean;
}
interface UseFileDialogReturn {
    files: Accessor<FileList | null>;
    open: (localOptions?: Partial<UseFileDialogOptions>) => void;
    reset: () => void;
    onChange: EventHookOn<FileList | null>;
}
/**
 * Open file dialog with ease.
 *
 * @see https://solidjs-use.github.io/solidjs-use/core/useFileDialog
 */
declare function useFileDialog(options?: UseFileDialogOptions): UseFileDialogReturn;

export { UseFileDialogOptions, UseFileDialogReturn, useFileDialog };
