import * as solid_js from 'solid-js';
import { UseScrollOptions, UseScrollReturn } from '../useScroll/index.js';
import { MaybeAccessor, Awaitable } from '@solidjs-use/shared';
import '@solidjs-use/shared/solid-to-vue';
import '../_configurable.js';

interface UseInfiniteScrollOptions extends UseScrollOptions {
    /**
     * The minimum distance between the bottom of the element and the bottom of the viewport
     *
     * @default 0
     */
    distance?: number;
    /**
     * The direction in which to listen the scroll.
     *
     * @default 'bottom'
     */
    direction?: "top" | "bottom" | "left" | "right";
    /**
     * The interval time between two load more (to avoid too many invokes).
     *
     * @default 100
     */
    interval?: number;
}
/**
 * Reactive infinite scroll.
 *
 * @see https://solidjs-use.github.io/solidjs-use/core/useInfiniteScroll
 */
declare function useInfiniteScroll(element: MaybeAccessor<HTMLElement | SVGElement | Window | Document | null | undefined>, onLoadMore: (state: UseScrollReturn) => Awaitable<void>, options?: UseInfiniteScrollOptions): {
    isLoading: solid_js.Accessor<boolean>;
};

export { UseInfiniteScrollOptions, useInfiniteScroll };
