import { Accessor } from 'solid-js';
import { ConfigurableWindow } from '../_configurable.js';

interface NavigatorLanguageState {
    isSupported: Accessor<boolean>;
    /**
     *
     * ISO 639-1 standard Language Code
     *
     * @info The detected user agent language preference as a language tag
     * (which is sometimes referred to as a "locale identifier").
     * This consists of a 2-3 letter base language tag that indicates a
     * language, optionally followed by additional subtags separated by
     * '-'. The most common extra information is the country or region
     * variant (like 'en-US' or 'fr-CA').
     *
     * @see https://www.iso.org/iso-639-language-codes.html
     * @see https://www.loc.gov/standards/iso639-2/php/code_list.php
     */
    language: Accessor<string | undefined>;
}
/**
 * Reactive useNavigatorLanguage.
 *
 * @see https://solidjs-use.github.io/solidjs-use/core/useNavigatorLanguage
 * @description Detects the currently selected user language and returns a reactive language
 */
declare const useNavigatorLanguage: (options?: ConfigurableWindow) => Readonly<NavigatorLanguageState>;
type UseNavigatorLanguageReturn = ReturnType<typeof useNavigatorLanguage>;

export { NavigatorLanguageState, UseNavigatorLanguageReturn, useNavigatorLanguage };
