import { Accessor } from 'solid-js';
import { ConfigurableWindow } from '../_configurable.js';

type NetworkType = 'bluetooth' | 'cellular' | 'ethernet' | 'none' | 'wifi' | 'wimax' | 'other' | 'unknown';
type NetworkEffectiveType = 'slow-2g' | '2g' | '3g' | '4g' | undefined;
interface NetworkState {
    isSupported: Accessor<boolean>;
    /**
     * If the user is currently connected.
     */
    isOnline: Accessor<boolean>;
    /**
     * The time since the user was last connected.
     */
    offlineAt: Accessor<number | undefined>;
    /**
     * At this time, if the user is offline and reconnects
     */
    onlineAt: Accessor<number | undefined>;
    /**
     * The download speed in Mbps.
     */
    downlink: Accessor<number | undefined>;
    /**
     * The max reachable download speed in Mbps.
     */
    downlinkMax: Accessor<number | undefined>;
    /**
     * The detected effective speed type.
     */
    effectiveType: Accessor<NetworkEffectiveType | undefined>;
    /**
     * The estimated effective round-trip time of the current connection.
     */
    rtt: Accessor<number | undefined>;
    /**
     * If the user activated data saver mode.
     */
    saveData: Accessor<boolean | undefined>;
    /**
     * The detected connection/network type.
     */
    type: Accessor<NetworkType>;
}
/**
 * Reactive Network status.
 *
 * @see https://solidjs-use.github.io/solidjs-use/core/useNetwork
 */
declare function useNetwork(options?: ConfigurableWindow): Readonly<NetworkState>;
type UseNetworkReturn = ReturnType<typeof useNetwork>;

export { NetworkEffectiveType, NetworkState, NetworkType, UseNetworkReturn, useNetwork };
