import * as solid_js from 'solid-js';
import { MaybeAccessor } from '@solidjs-use/shared';
import { ConfigurableWindow } from '../_configurable.js';

type UseSpeechSynthesisStatus = "init" | "play" | "pause" | "end";
interface UseSpeechSynthesisOptions extends ConfigurableWindow {
    /**
     * Language for SpeechSynthesis
     *
     * @default 'en-US'
     */
    lang?: MaybeAccessor<string>;
    /**
     * Gets and sets the pitch at which the utterance will be spoken at.
     *
     * @default 1
     */
    pitch?: MaybeAccessor<SpeechSynthesisUtterance["pitch"]>;
    /**
     * Gets and sets the speed at which the utterance will be spoken at.
     *
     * @default 1
     */
    rate?: MaybeAccessor<SpeechSynthesisUtterance["rate"]>;
    /**
     * Gets and sets the voice that will be used to speak the utterance.
     */
    voice?: MaybeAccessor<SpeechSynthesisVoice>;
    /**
     * Gets and sets the volume that the utterance will be spoken at.
     *
     * @default 1
     */
    volume?: SpeechSynthesisUtterance["volume"];
}
/**
 * Reactive SpeechSynthesis.
 *
 * @see https://solidjs-use.github.io/solidjs-use/core/useSpeechSynthesis
 * @see https://developer.mozilla.org/en-US/docs/Web/API/SpeechSynthesis SpeechSynthesis
 */
declare function useSpeechSynthesis(text: MaybeAccessor<string>, options?: UseSpeechSynthesisOptions): {
    isSupported: solid_js.Accessor<boolean>;
    isPlaying: solid_js.Accessor<boolean>;
    status: solid_js.Accessor<UseSpeechSynthesisStatus>;
    utterance: solid_js.Accessor<SpeechSynthesisUtterance>;
    error: solid_js.Accessor<SpeechSynthesisErrorEvent | undefined>;
    stop: () => void;
    toggle: (value?: boolean) => void;
    speak: () => void;
};
type UseSpeechSynthesisReturn = ReturnType<typeof useSpeechSynthesis>;

export { UseSpeechSynthesisOptions, UseSpeechSynthesisReturn, UseSpeechSynthesisStatus, useSpeechSynthesis };
