import { Accessor } from 'solid-js';
import { SimpleSetter } from '@solidjs-use/shared/solid-to-vue';
import { MaybeSignal } from '@solidjs-use/shared';
import { ConfigurableDocument } from '../_configurable.js';

interface UseStyleTagOptions extends ConfigurableDocument {
    /**
     * Media query for styles to apply
     */
    media?: string;
    /**
     * Load the style immediately
     *
     * @default true
     */
    immediate?: boolean;
    /**
     * Manual controls the timing of loading and unloading
     *
     * @default false
     */
    manual?: boolean;
    /**
     * DOM id of the style tag
     *
     * @default auto-incremented
     */
    id?: string;
}
interface UseStyleTagReturn {
    id: string;
    css: Accessor<string>;
    setCss: SimpleSetter<string>;
    load: () => void;
    unload: () => void;
    isLoaded: Accessor<boolean>;
}
/**
 * Inject <style> element in head.
 *
 * @see https://solidjs-use.github.io/solidjs-use/core/useStyleTag
 */
declare function useStyleTag(css: MaybeSignal<string>, options?: UseStyleTagOptions): UseStyleTagReturn;

export { UseStyleTagOptions, UseStyleTagReturn, useStyleTag };
