import * as solid_js from 'solid-js';
import { ConfigurableDocument } from '../_configurable.js';

type UseTextDirectionValue = 'ltr' | 'rtl' | 'auto';
interface UseTextDirectionOptions extends ConfigurableDocument {
    /**
     * CSS Selector for the target element applying to
     *
     * @default 'html'
     */
    selector?: string;
    /**
     * Observe `document.querySelector(selector)` changes using MutationObserve
     *
     * @default false
     */
    observe?: boolean;
    /**
     * Initial value
     *
     * @default 'ltr'
     */
    initialValue?: UseTextDirectionValue;
}
/**
 * Reactive dir of the element's text.
 *
 * @see https://solidjs-use.github.io/solidjs-use/core/useTextDirection
 */
declare function useTextDirection(options?: UseTextDirectionOptions): {
    dir: solid_js.Accessor<UseTextDirectionValue>;
    setDir: (v: UseTextDirectionValue) => void;
};

export { UseTextDirectionOptions, UseTextDirectionValue, useTextDirection };
