import * as solid_js from 'solid-js';
import { JSX } from 'solid-js';
import { MaybeAccessor, EffectOnDeps } from '@solidjs-use/shared';

interface UseTextareaAutoSizeOptions {
    /** Textarea element to autosize. */
    element?: MaybeAccessor<HTMLTextAreaElement | undefined>;
    /** Textarea content. */
    input?: MaybeAccessor<string | undefined>;
    /** Watch sources that should trigger a textarea resize. */
    deps?: EffectOnDeps;
    /** Function called when the textarea size changes. */
    onResize?: () => void;
    /** Specify style target to apply the height based on textarea content. If not provided it will use textarea it self.  */
    styleTarget?: MaybeAccessor<HTMLElement>;
}
/**
 * Automatically update the height of a textarea depending on the content.
 *
 * @see https://solidjs-use.github.io/solidjs-use/core/useTextareaAutoSize
 */
declare function useTextareaAutoSize(options?: UseTextareaAutoSizeOptions): {
    setTextareaRef: solid_js.Setter<HTMLTextAreaElement>;
    value: solid_js.Accessor<string>;
    onChange: JSX.ChangeEventHandler<HTMLTextAreaElement, Event>;
    triggerResize: () => void;
};
type UseTextareaAutoSizeReturn = ReturnType<typeof useTextareaAutoSize>;

export { UseTextareaAutoSizeOptions, UseTextareaAutoSizeReturn, useTextareaAutoSize };
