import { Accessor, Signal } from 'solid-js';
import { MaybeAccessor } from '@solidjs-use/shared';
import { ConfigurableDocument } from '../_configurable.js';

type UseTitleOptionsBase = {
    /**
     * Observe `document.title` changes using MutationObserve
     * Cannot be used together with `titleTemplate` option.
     *
     * @default false
     */
    observe?: boolean;
} | {
    /**
     * The template string to parse the title (e.g., '%s | My Website')
     * Cannot be used together with `observe` option.
     *
     * @default '%s'
     */
    titleTemplate?: MaybeAccessor<string> | ((title: string) => string);
};
type UseTitleOptions = ConfigurableDocument & UseTitleOptionsBase;
declare function useTitle(newTitle: Accessor<string | null | undefined>, options?: UseTitleOptions): Accessor<string | null | undefined>;
declare function useTitle(newTitle?: string | null | undefined, options?: UseTitleOptions): Signal<string | null | undefined>;
type UseTitleReturn = ReturnType<typeof useTitle>;

export { UseTitleOptions, UseTitleOptionsBase, UseTitleReturn, useTitle };
