import { Signal } from 'solid-js';
import { ConfigurableWindow } from '../_configurable.js';

type UrlParams = Record<string, string[] | string>;
interface UseUrlSearchParamsOptions<T> extends ConfigurableWindow {
    /**
     * @default true
     */
    removeNullishValues?: boolean;
    /**
     * @default false
     */
    removeFalsyValues?: boolean;
    /**
     * @default {}
     */
    initialValue?: T;
    /**
     * Write back to `window.history` automatically
     *
     * @default true
     */
    write?: boolean;
}
/**
 * Reactive URLSearchParams.
 *
 * @see https://solidjs-use.github.io/solidjs-use/core/useUrlSearchParams
 */
declare function useUrlSearchParams<T extends Record<string, any> = UrlParams>(mode?: 'history' | 'hash' | 'hash-params', options?: UseUrlSearchParamsOptions<T>): Signal<T>;

export { UrlParams, UseUrlSearchParamsOptions, useUrlSearchParams };
