import * as solid_js from 'solid-js';
import { ConfigurableWindow } from '../_configurable.js';

interface UseWindowSizeOptions extends ConfigurableWindow {
    initialWidth?: number;
    initialHeight?: number;
    /**
     * Listen to window `orientationchange` event
     *
     * @default true
     */
    listenOrientation?: boolean;
    /**
     * Whether the scrollbar should be included in the width and height
     * @default true
     */
    includeScrollbar?: boolean;
}
/**
 * Reactive window size.
 *
 * @see https://solidjs-use.github.io/solidjs-use/core/useWindowSize
 */
declare function useWindowSize(options?: UseWindowSizeOptions): {
    width: solid_js.Accessor<number>;
    height: solid_js.Accessor<number>;
};
type UseWindowSizeReturn = ReturnType<typeof useWindowSize>;

export { UseWindowSizeOptions, UseWindowSizeReturn, useWindowSize };
